---
template: mainpanel
source_form: markdown
name: Trello Cardlist Known Bugs / Anti-features
updated: October 2016
title: Trello Cardlist Known Bugs / Anti-features
---
### Known Bugs / Anti-features

